pub fn run(project_path: &Path, format: &OutputFormat) -> Result<String>Expand description
Run dependency analysis on the given project path.
Detects dependency files, parses them, applies rules, and returns a formatted report string.
pub fn run(project_path: &Path, format: &OutputFormat) -> Result<String>Run dependency analysis on the given project path.
Detects dependency files, parses them, applies rules, and returns a formatted report string.