Module duplication

Module duplication 

Structs

CodeDuplicationRule
code duplication detection rule with smart anti-false-positive logic

Functions

get_rust_patterns_for_testing
Get the list of Rust common pattern strings for testing purposes. This provides controlled access to internal patterns without exposing the raw static.