Functions
- count_
non_ comment_ matches - Count non-comment occurrences of a pattern in source content
- count_
non_ import_ matches - Count non-comment, non-import occurrences of a pattern in source content
- find_
line_ of_ str - Find the line number of a string literal in source content (skipping comments)
- find_
line_ of_ str_ non_ import - Find the line number of a string literal, skipping comments and import statements
- get_
column_ number - Get column number from syn AST node using proc_macro2 span-locations
- get_
line_ number - Get line number from syn AST node using proc_macro2 span-locations
- get_
position - Get position info (line, column) from syn AST node